using System;
using System.Collections.Generic;
using System.Text;
using System.Reflection;

namespace DTLoggedExec.LogProviders
{
    public class NullLogProvider: ILogProvider  
    {
        #region ILogProvider Members

        public void Configure(string configurationString)
        {
            // No configuration needed
            return;
        }

        public void SetExecutionGuid(Guid executionGuid)
        {
            // No need to store execution GUID
            return;
        }

        public void SetPackageInfo(Uri packageUri)
        {
            // No need to store Package info
            return;
        }

        public void ShowVersionInformation()
        {
            Assembly executingAssembly = System.Reflection.Assembly.GetExecutingAssembly();
            string copyright = ((AssemblyCopyrightAttribute)executingAssembly.GetCustomAttributes(typeof(AssemblyCopyrightAttribute), true)[0]).Copyright;
            string version = executingAssembly.GetName().Version.ToString();

            Console.WriteLine("NullLogProvider " + copyright + " v." + version);
        }

        
        public void LogStartPackageExecution(Microsoft.SqlServer.Dts.Runtime.Package package)
        {
            return;
        }

        public void LogEndPackageExecution(Microsoft.SqlServer.Dts.Runtime.Package package, int warningCount, int errorCount, Microsoft.SqlServer.Dts.Runtime.DTSExecResult result)
        {
            return;
        }

        public void LogEndPackageExecution(Microsoft.SqlServer.Dts.Runtime.Package package, int warningCount, int errorCount, Microsoft.SqlServer.Dts.Runtime.DTSExecResult result, Microsoft.SqlServer.Dts.Runtime.DtsException exception)
        {
            return;
        }

        public void LogEventData(string eventName, Microsoft.SqlServer.Dts.Runtime.DtsObject dtsobj, string messages)
        {
            return;
        }

        public void LogStartPackageLoading()
        {
            return;
        }

        public void LogEndPackageLoading()
        {
            return;
        }

        public void LogEndPackageLoading(Exception exception)
        {
            return;
        }

        #endregion

        #region IDisposable Members

        public void Dispose()
        {
            return;
        }

        #endregion
    }
}
